@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,7 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ *  $Id: ephy-bookmarks-import.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #ifndef EPHY_BOOKMARKS_IMPORT_H
@@ -23,9 +26,12 @@
 
 G_BEGIN_DECLS
 
-#define MOZILLA_BOOKMARKS_DIR ".mozilla"
-#define GALEON_BOOKMARKS_DIR ".galeon"
-#define KDE_BOOKMARKS_DIR ".kde/share/apps/konqueror"
+#define MOZILLA_BOOKMARKS_DIR	".mozilla"
+#define FIREFOX_BOOKMARKS_DIR_0	".phoenix"
+#define FIREFOX_BOOKMARKS_DIR_1	".firefox"
+#define FIREFOX_BOOKMARKS_DIR_2	".mozilla/firefox"
+#define GALEON_BOOKMARKS_DIR	".galeon"
+#define KDE_BOOKMARKS_DIR	".kde/share/apps/konqueror"
 
 gboolean ephy_bookmarks_import         (EphyBookmarks *bookmarks,
 					const char *filename);
