@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-go-action.c 6997 2007-04-16 07:19:36Z diegoe $
+ *  $Id: ephy-go-action.c 7072 2007-06-05 20:20:24Z diegoe $
  */
 
 #include "config.h"
@@ -95,7 +95,7 @@ connect_proxy (GtkAction *action,
 
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
-		g_signal_connect (GTK_BIN (proxy)->child, "button-press-event",
+		g_signal_connect (GTK_BIN (proxy)->child, "button-release-event",
 					 G_CALLBACK (button_clicked_cb), action
 					);
 	}
