@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 200-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 200-2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: prefs-dialog.c,v 1.126 2006/07/21 19:57:05 chpe Exp $
+ *  $Id: prefs-dialog.c 7032 2007-05-19 16:40:23Z chpe $
  */
 
 #include "config.h"
@@ -102,8 +102,7 @@ static const char * const size_prefs [] =
 	CONF_RENDERING_FONT_MIN_SIZE
 };
 
-const
-int default_size [] =
+static const int default_size [] =
 {
 	10,
 	11,
@@ -300,7 +299,7 @@ prefs_dialog_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (PrefsDialogClass),
 			NULL, /* base_init */
@@ -371,7 +370,7 @@ prefs_dialog_show_help (EphyDialog *dialog)
 	GtkWidget *window, *notebook;
 	int id;
 
-	static char * const help_preferences[] = {
+	static const char help_preferences[][28] = {
 		"general-preferences",
 		"fonts-and-style-preferences",
 		"privacy-preferences",
